function [tt,u]=rk4(odefun,tspan,y0,Nh,varargin);
%RK4  Risolve equazioni differenziali
%   usando il metodo di Runge-Kutta4 esplicito.
%   [tn,un] = rk4(odefun,tspan,y0,Nh) con
%   TSPAN = [T0,TF] integra il sistema di equazioni
%   differenziali y' = f(t,y) dal tempo T0 a TF con
%   condizione iniziale Y0 usando il metodo di 
%   Runge-Kutta4 esplicito su una griglia equispaziata di 
%   Nh intervalli.
%   La funzione ODEFUN(T,Y) deve ritornare un vettore
%   contenente f(t,y), della stessa dimensione di y.
%   Ogni riga del vettore soluzione Y corrisponde ad
%   un istante temporale del vettore colonna T.
%   [T,Y] = RK4(ODEFUN,TSPAN,Y0,NH,P1,P2,...) passa
%   i parametri addizionali P1,P2,... alla funzione
%   ODEFUN come ODEFUN(T,Y,P1,P2...).

tt=linspace(tspan(1),tspan(2),Nh+1);
h=(tspan(2)-tspan(1))/Nh; hh=h*0.5; 
y=y0(:);
w=y; u=y.';
h6=h/6;
for t=tt(1:end-1)
  
  k1=feval(odefun,t,w,varargin{:});
  t1 = t + hh; w1 = w + hh* k1;
  k2=feval(odefun,t1,w1,varargin{:});
  w1 = w + hh* k2;
  k3=feval(odefun,t1,w1,varargin{:});
  t1 = t + h; w1 = w + h*k3;
  k4=feval(odefun,t1,w1,varargin{:});
  w=w + h6*(k1+2*k2+2*k3+k4);
  u = [u; w.'];

end

tt=tt';

